Fast ConfigParser
=================

.. image:: https://gitlab.com/onegreyonewhite/configparserc/badges/master/pipeline.svg
    :target: https://gitlab.com/onegreyonewhite/configparserc/commits/master
    :alt: Pipeline status

.. image:: https://gitlab.com/onegreyonewhite/configparserc/badges/master/coverage.svg
    :target: https://gitlab.com/onegreyonewhite/configparserc/pipelines
    :alt: Coverage report

.. image:: https://badge.fury.io/py/configparserc.svg
    :target: https://badge.fury.io/py/configparserc


Python (Cython) based implementation of ConfigParser based on POSIX and stdlib functions.
Wrapped via Cython, uses POSIX stat and libc stdio functions for read file.


Authors
-------

Author:
    Sergey Klyuykov <onegreyonewhite@mail.ru>


Contributor(s):
    Kirill Bychkov <kirill970528@yandex.ru>


License
-------

VSTUtils is licensed under the terms of the Apache License 2.0.
See the file "LICENSE" for more information.

Copyright 2019-2020 Sergey Klyuykov
